@@ -32,6 +32,7 @@
     ObjectGetOwnPropertyDescriptor,
     ObjectPrototypeIsPrototypeOf,
     ReflectDefineProperty,
+    ReflectHas,
     SafeArrayIterator,
     StringPrototypeStartsWith,
     Symbol,
@@ -104,7 +105,7 @@
   function hasRelatedTarget(
     event,
   ) {
-    return "relatedTarget" in event;
+    return ReflectHas(event, "relatedTarget");
   }
 
   const isTrusted = ObjectGetOwnPropertyDescriptor({
@@ -450,7 +451,7 @@
   function isNode(
     eventTarget,
   ) {
-    return Boolean(eventTarget && "nodeType" in eventTarget);
+    return Boolean(eventTarget && ReflectHas(eventTarget, "nodeType"));
   }
 
   // https://dom.spec.whatwg.org/#concept-shadow-including-inclusive-ancestor
@@ -485,7 +486,7 @@
   function isSlotable(
     nodeImpl,
   ) {
-    return Boolean(isNode(nodeImpl) && "assignedSlot" in nodeImpl);
+    return Boolean(isNode(nodeImpl) && ReflectHas(nodeImpl, "assignedSlot"));
   }
 
   // DOM Logic functions
@@ -908,7 +909,7 @@
       options = normalizeAddEventHandlerOptions(options);
       const { listeners } = (this ?? globalThis)[eventTargetData];
 
-      if (!(type in listeners)) {
+      if (!(ReflectHas(listeners, type))) {
         listeners[type] = [];
       }
 
@@ -952,7 +953,7 @@
       });
 
       const { listeners } = (this ?? globalThis)[eventTargetData];
-      if (callback !== null && type in listeners) {
+      if (callback !== null && ReflectHas(listeners, type)) {
         listeners[type] = ArrayPrototypeFilter(
           listeners[type],
           (listener) => listener.callback !== callback,
@@ -989,7 +990,7 @@
       const self = this ?? window;
 
       const { listeners } = self[eventTargetData];
-      if (!(event.type in listeners)) {
+      if (!ReflectHas(listeners, event.type)) {
         setTarget(event, this);
         return true;
       }
@@ -1366,6 +1367,20 @@
     reportExceptionStackedCalls--;
   }
 
+  function checkThis(thisArg) {
+    if (thisArg !== null && thisArg !== undefined && thisArg !== globalThis) {
+      throw new TypeError("Illegal invocation");
+    }
+  }
+
+  // https://html.spec.whatwg.org/#dom-reporterror
+  function reportError(error) {
+    checkThis(this);
+    const prefix = "Failed to call 'reportError'";
+    webidl.requiredArguments(arguments.length, 1, { prefix });
+    reportException(error);
+  }
+
   window.Event = Event;
   window.EventTarget = EventTarget;
   window.ErrorEvent = ErrorEvent;
@@ -1376,6 +1391,7 @@
   window.dispatchEvent = EventTarget.prototype.dispatchEvent;
   window.addEventListener = EventTarget.prototype.addEventListener;
   window.removeEventListener = EventTarget.prototype.removeEventListener;
+  window.reportError = reportError;
   window.__bootstrap.eventTarget = {
     EventTarget,
     setEventTargetData,
