@@ -28,12 +28,15 @@
     MapPrototypeGet,
     MapPrototypeSet,
     ObjectDefineProperty,
+    ObjectPrototypeIsPrototypeOf,
     queueMicrotask,
+    SafeArrayIterator,
     StringFromCodePoint,
     Symbol,
     TypedArrayPrototypeSet,
     TypeError,
     Uint8Array,
+    Uint8ArrayPrototype,
   } = window.__bootstrap.primordials;
 
   const state = Symbol("[[state]]");
@@ -116,7 +119,10 @@
 
             // 4. If chunkPromise is fulfilled with an object whose done property is false
             // and whose value property is a Uint8Array object, run these steps:
-            if (!chunk.done && chunk.value instanceof Uint8Array) {
+            if (
+              !chunk.done &&
+              ObjectPrototypeIsPrototypeOf(Uint8ArrayPrototype, chunk.value)
+            ) {
               ArrayPrototypePush(chunks, chunk.value);
 
               // TODO(bartlomieju): (only) If roughly 50ms have passed since last progress
@@ -260,7 +266,7 @@
     }
 
     #getEventHandlerFor(name) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
 
       const maybeMap = this[handlerSymbol];
       if (!maybeMap) return null;
@@ -269,7 +275,7 @@
     }
 
     #setEventHandlerFor(name, value) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
 
       if (!this[handlerSymbol]) {
         this[handlerSymbol] = new Map();
@@ -292,7 +298,7 @@
 
     /** @returns {number} */
     get readyState() {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       switch (this[state]) {
         case "empty":
           return FileReader.EMPTY;
@@ -306,17 +312,17 @@
     }
 
     get result() {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       return this[result];
     }
 
     get error() {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       return this[error];
     }
 
     abort() {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       // If context object's state is "empty" or if context object's state is "done" set context object's result to null and terminate this algorithm.
       if (
         this[state] === "empty" ||
@@ -349,7 +355,7 @@
 
     /** @param {Blob} blob */
     readAsArrayBuffer(blob) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       const prefix = "Failed to execute 'readAsArrayBuffer' on 'FileReader'";
       webidl.requiredArguments(arguments.length, 1, { prefix });
       this.#readOperation(blob, { kind: "ArrayBuffer" });
@@ -357,7 +363,7 @@
 
     /** @param {Blob} blob */
     readAsBinaryString(blob) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       const prefix = "Failed to execute 'readAsBinaryString' on 'FileReader'";
       webidl.requiredArguments(arguments.length, 1, { prefix });
       // alias for readAsArrayBuffer
@@ -366,7 +372,7 @@
 
     /** @param {Blob} blob */
     readAsDataURL(blob) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       const prefix = "Failed to execute 'readAsDataURL' on 'FileReader'";
       webidl.requiredArguments(arguments.length, 1, { prefix });
       // alias for readAsArrayBuffer
@@ -378,7 +384,7 @@
      * @param {string} [encoding]
      */
     readAsText(blob, encoding = undefined) {
-      webidl.assertBranded(this, FileReader);
+      webidl.assertBranded(this, FileReaderPrototype);
       const prefix = "Failed to execute 'readAsText' on 'FileReader'";
       webidl.requiredArguments(arguments.length, 1, { prefix });
       if (encoding !== undefined) {
@@ -435,6 +441,7 @@
   }
 
   webidl.configurePrototype(FileReader);
+  const FileReaderPrototype = FileReader.prototype;
 
   ObjectDefineProperty(FileReader, "EMPTY", {
     writable: false,
@@ -478,7 +485,11 @@
       if (typeof wrappedHandler.handler !== "function") {
         return;
       }
-      return FunctionPrototypeCall(wrappedHandler.handler, this, ...args);
+      return FunctionPrototypeCall(
+        wrappedHandler.handler,
+        this,
+        ...new SafeArrayIterator(args),
+      );
     }
     wrappedHandler.handler = handler;
     return wrappedHandler;
